Package: Deducer
Version: 0.9-2
Date: 2026-05-05
Title: A Data Analysis GUI for R
Authors@R: c(person(given = "Ian",
                      family = "Fellows",
                      role = c("aut","cre"),
                      email = "ian@fellstat.com"))
Maintainer: Ian Fellows <ian@fellstat.com>
Description: An intuitive, cross-platform graphical data analysis system. It uses menus and dialogs to guide the user efficiently through the data manipulation and analysis process, and has an excel like spreadsheet for easy data frame visualization and editing. Deducer works best when used with the Java based R GUI JGR, but the dialogs can be called from the command line. Dialogs have also been integrated into the Windows Rgui.
Depends: R (>= 2.15.0), ggplot2 (>= 2.0.0), JGR(>= 1.7-10), car, MASS
Imports: rJava, e1071, scales, plyr, foreign, multcomp, effects
Suggests: Hmisc, brunnermunzel, cli
SystemRequirements: Java, JRI
License: GPL-2
URL: https://www.deducer.org/ https://www.fellstat.com
NeedsCompilation: no
Packaged: 2026-05-06 08:25:26 UTC; ianfellows
Author: Ian Fellows [aut, cre]
Repository: CRAN
Date/Publication: 2026-05-06 21:10:02 UTC
Built: R 4.5.2; ; 2026-05-06 23:33:37 UTC; unix
