exportPattern("[[:alpha:]]+")
import(rJava)
import(JGR)
import(MASS)
import(car)
import(e1071, except=element)
import(effects)
import(foreign)
importFrom(scales, ContinuousRange,
 DiscreteRange,
 abs_area,
 area_pal,
 as.trans,
 asn_trans,
 atanh_trans,
 boxcox_trans,
 brewer_pal,
 cbreaks,
 censor,
 col2hcl,
 col_bin,
 col_factor,
 col_numeric,
 col_quantile,
 colour_ramp,
 comma,
 comma_format,
 cscale,
 date_breaks,
 date_format,
 date_trans,
 dichromat_pal,
 discard,
 div_gradient_pal,
 dollar,
 dollar_format,
 dscale,
 exp_trans,
 expand_range,
 extended_breaks,
 format_format,
 fullseq,
 gradient_n_pal,
 grey_pal,
 hue_pal,
 identity_pal,
 identity_trans,
 is.trans,
 linetype_pal,
 log10_trans,
 log1p_trans,
 log2_trans,
 log_breaks,
 log_trans,
 logit_trans,
 manual_pal,
 math_format,
 muted,
 ordinal,
 ordinal_format,
 parse_format,
 percent,
 percent_format,
 pretty_breaks,
 probability_trans,
 probit_trans,
 reciprocal_trans,
 rescale,
 rescale_max,
 rescale_mid,
 rescale_none,
 rescale_pal,
 reverse_trans,
 scientific,
 scientific_format,
 seq_gradient_pal,
 shape_pal,
 show_col,
 sqrt_trans,
 squish,
 squish_infinite,
 time_trans,
 train_continuous,
 train_discrete,
 trans_breaks,
 trans_format,
 trans_new,
 trans_range,
 unit_format,
 wrap_format,
 zero_range)
import(ggplot2)
import(multcomp)
import(plyr)
importFrom("stats", "as.formula", "chisq.test", "coef",
             "complete.cases", "cor", "cor.test", "fisher.test",
             "kruskal.test", "mantelhaen.test", "median", "na.omit",
             "oneway.test", "pchisq", "pt", "quantile", "relevel", "sd",
             "t.test", "var")
importFrom("utils", "capture.output", "menu")

S3method(plot, cor.matrix)
S3method(print, contin.table)
S3method(print,  contin.tests)
S3method(print,  contingency.tables)
S3method(print,  cor.matrix)
S3method(print,  freq.table)
S3method(print,  multi.test)

S3method(as.matrix,cor.matrix)
S3method(sort,data.frame)