
\name{deducer}
\alias{deducer}
\alias{data.viewer}
\title{GUI Access functions}
\description{
  splits a variable into two groups
}
\usage{
deducer(cmd=NULL)

data.viewer()
}
\arguments{
  \item{cmd}{The command to be executed}
}

